@@ -14,7 +14,7 @@ use constant SKIP      => 2;
 #inherits Apache::Session
 #link Lemonldap::NG::Common::Apache::Session::SOAP protected globalStorage
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.2';
 our ( %EXPORT_TAGS, @EXPORT_OK, @EXPORT );
 
 our $tsv = {};    # Hash ref containing thread-shared values, filled
@@ -547,9 +547,7 @@ sub status($$) {
 # @param $f Current Apache2::Filter object
 # @return Constant OK
 sub redirectFilter {
-    my $class = shift;
-    my $url   = shift;
-    my $f     = shift;
+    my ( $class, $url, $f ) = @_;
     unless ( $f->ctx ) {
 
         # Here, we can use Apache2 functions instead of set_header_out
@@ -588,9 +586,22 @@ sub isUnprotected {
 sub sendHeaders {
     my $class = shift;
     my $vhost = $class->resolveAlias;
+
     if ( defined( $tsv->{forgeHeaders}->{$vhost} ) ) {
-        Lemonldap::NG::Handler::API->set_header_in(
-            &{ $tsv->{forgeHeaders}->{$vhost} } );
+
+        # Log headers in debug mode
+        my %headers = &{ $tsv->{forgeHeaders}->{$vhost} };
+        foreach my $h ( sort keys %headers ) {
+            if ( defined( my $v = $headers{$h} ) ) {
+                Lemonldap::NG::Handler::Main::Logger->lmLog(
+                    "Send header $h with value $v", "debug" );
+            }
+            else {
+                Lemonldap::NG::Handler::Main::Logger->lmLog(
+                    "Send header $h with empty value", "debug" );
+            }
+        }
+        Lemonldap::NG::Handler::API->set_header_in(%headers);
     }
 }
 
